@@ -5,6 +5,8 @@ use elbus::rpc::{self, RpcClient, RpcHandlers};
 use serde::{Deserialize, Serialize};
 use std::collections::HashMap;
 use std::fmt;
+#[cfg(feature = "extended-config")]
+use std::path::Path;
 use std::sync::Arc;
 use std::time::Duration;
 
@@ -213,6 +215,11 @@ impl Initial {
     pub fn config(&self) -> Option<&Value> {
         self.config.as_ref()
     }
+    #[cfg(feature = "extended-config")]
+    #[inline]
+    pub async fn extend_config(&mut self, timeout: Duration, base: &Path) {
+        self.config = self.config.extend(timeout, base).await;
+    }
     #[inline]
     pub fn workers(&self) -> u32 {
         self.workers
